@@ -36,10 +36,8 @@ class CfnDataCatalog(
 ):
     """A CloudFormation ``AWS::Athena::DataCatalog``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Athena::DataCatalog
+    :cloudformationResource: AWS::Athena::DataCatalog
     """
 
     def __init__(
@@ -51,7 +49,7 @@ class CfnDataCatalog(
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional["TagsProperty"] = None,
+        tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
     ) -> None:
         """Create a new ``AWS::Athena::DataCatalog``.
 
@@ -75,11 +73,10 @@ class CfnDataCatalog(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -110,7 +107,6 @@ class CfnDataCatalog(
     def tags(self) -> aws_cdk.core.TagManager:
         """``AWS::Athena::DataCatalog.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
         """
         return jsii.get(self, "tags")
@@ -120,7 +116,6 @@ class CfnDataCatalog(
     def name(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-name
         """
         return jsii.get(self, "name")
@@ -134,7 +129,6 @@ class CfnDataCatalog(
     def type(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-type
         """
         return jsii.get(self, "type")
@@ -148,7 +142,6 @@ class CfnDataCatalog(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::DataCatalog.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-description
         """
         return jsii.get(self, "description")
@@ -164,7 +157,6 @@ class CfnDataCatalog(
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]]:
         """``AWS::Athena::DataCatalog.Parameters``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-parameters
         """
         return jsii.get(self, "parameters")
@@ -190,7 +182,6 @@ class CfnDataCatalog(
             """
             :param tags: ``CfnDataCatalog.TagsProperty.Tags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -201,7 +192,6 @@ class CfnDataCatalog(
         def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
             """``CfnDataCatalog.TagsProperty.Tags``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html#cfn-athena-datacatalog-tags-tags
             """
             result = self._values.get("tags")
@@ -238,7 +228,7 @@ class CfnDataCatalogProps:
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
+        tags: typing.Optional[CfnDataCatalog.TagsProperty] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::DataCatalog``.
 
@@ -248,7 +238,6 @@ class CfnDataCatalogProps:
         :param parameters: ``AWS::Athena::DataCatalog.Parameters``.
         :param tags: ``AWS::Athena::DataCatalog.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
         """
         if isinstance(tags, dict):
@@ -268,7 +257,6 @@ class CfnDataCatalogProps:
     def name(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-name
         """
         result = self._values.get("name")
@@ -279,7 +267,6 @@ class CfnDataCatalogProps:
     def type(self) -> builtins.str:
         """``AWS::Athena::DataCatalog.Type``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-type
         """
         result = self._values.get("type")
@@ -290,7 +277,6 @@ class CfnDataCatalogProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::DataCatalog.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-description
         """
         result = self._values.get("description")
@@ -302,17 +288,15 @@ class CfnDataCatalogProps:
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]]:
         """``AWS::Athena::DataCatalog.Parameters``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-parameters
         """
         result = self._values.get("parameters")
         return result
 
     @builtins.property
-    def tags(self) -> typing.Optional["CfnDataCatalog.TagsProperty"]:
+    def tags(self) -> typing.Optional[CfnDataCatalog.TagsProperty]:
         """``AWS::Athena::DataCatalog.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
         """
         result = self._values.get("tags")
@@ -338,10 +322,8 @@ class CfnNamedQuery(
 ):
     """A CloudFormation ``AWS::Athena::NamedQuery``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Athena::NamedQuery
+    :cloudformationResource: AWS::Athena::NamedQuery
     """
 
     def __init__(
@@ -374,11 +356,10 @@ class CfnNamedQuery(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -403,8 +384,7 @@ class CfnNamedQuery(
     @jsii.member(jsii_name="attrNamedQueryId")
     def attr_named_query_id(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: NamedQueryId
+        :cloudformationAttribute: NamedQueryId
         """
         return jsii.get(self, "attrNamedQueryId")
 
@@ -418,7 +398,6 @@ class CfnNamedQuery(
     def database(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.Database``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-database
         """
         return jsii.get(self, "database")
@@ -432,7 +411,6 @@ class CfnNamedQuery(
     def query_string(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.QueryString``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-querystring
         """
         return jsii.get(self, "queryString")
@@ -446,7 +424,6 @@ class CfnNamedQuery(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-description
         """
         return jsii.get(self, "description")
@@ -460,7 +437,6 @@ class CfnNamedQuery(
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-name
         """
         return jsii.get(self, "name")
@@ -496,7 +472,6 @@ class CfnNamedQueryProps:
         :param description: ``AWS::Athena::NamedQuery.Description``.
         :param name: ``AWS::Athena::NamedQuery.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -512,7 +487,6 @@ class CfnNamedQueryProps:
     def database(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.Database``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-database
         """
         result = self._values.get("database")
@@ -523,7 +497,6 @@ class CfnNamedQueryProps:
     def query_string(self) -> builtins.str:
         """``AWS::Athena::NamedQuery.QueryString``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-querystring
         """
         result = self._values.get("query_string")
@@ -534,7 +507,6 @@ class CfnNamedQueryProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-description
         """
         result = self._values.get("description")
@@ -544,7 +516,6 @@ class CfnNamedQueryProps:
     def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::NamedQuery.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-name
         """
         result = self._values.get("name")
@@ -570,10 +541,8 @@ class CfnWorkGroup(
 ):
     """A CloudFormation ``AWS::Athena::WorkGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Athena::WorkGroup
+    :cloudformationResource: AWS::Athena::WorkGroup
     """
 
     def __init__(
@@ -586,8 +555,8 @@ class CfnWorkGroup(
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]] = None,
-        work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]] = None,
-        work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]] = None,
+        work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::Athena::WorkGroup``.
 
@@ -615,11 +584,10 @@ class CfnWorkGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -644,8 +612,7 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="attrCreationTime")
     def attr_creation_time(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: CreationTime
+        :cloudformationAttribute: CreationTime
         """
         return jsii.get(self, "attrCreationTime")
 
@@ -659,7 +626,6 @@ class CfnWorkGroup(
     def tags(self) -> aws_cdk.core.TagManager:
         """``AWS::Athena::WorkGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-tags
         """
         return jsii.get(self, "tags")
@@ -669,7 +635,6 @@ class CfnWorkGroup(
     def name(self) -> builtins.str:
         """``AWS::Athena::WorkGroup.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-name
         """
         return jsii.get(self, "name")
@@ -683,7 +648,6 @@ class CfnWorkGroup(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-description
         """
         return jsii.get(self, "description")
@@ -699,7 +663,6 @@ class CfnWorkGroup(
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::Athena::WorkGroup.RecursiveDeleteOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-recursivedeleteoption
         """
         return jsii.get(self, "recursiveDeleteOption")
@@ -716,7 +679,6 @@ class CfnWorkGroup(
     def state(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-state
         """
         return jsii.get(self, "state")
@@ -729,10 +691,9 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfiguration")
     def work_group_configuration(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfiguration
         """
         return jsii.get(self, "workGroupConfiguration")
@@ -740,7 +701,7 @@ class CfnWorkGroup(
     @work_group_configuration.setter # type: ignore
     def work_group_configuration(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]],
     ) -> None:
         jsii.set(self, "workGroupConfiguration", value)
 
@@ -748,10 +709,9 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfigurationUpdates")
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfigurationupdates
         """
         return jsii.get(self, "workGroupConfigurationUpdates")
@@ -759,7 +719,7 @@ class CfnWorkGroup(
     @work_group_configuration_updates.setter # type: ignore
     def work_group_configuration_updates(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]],
     ) -> None:
         jsii.set(self, "workGroupConfigurationUpdates", value)
 
@@ -779,7 +739,6 @@ class CfnWorkGroup(
             :param encryption_option: ``CfnWorkGroup.EncryptionConfigurationProperty.EncryptionOption``.
             :param kms_key: ``CfnWorkGroup.EncryptionConfigurationProperty.KmsKey``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-encryptionconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -792,7 +751,6 @@ class CfnWorkGroup(
         def encryption_option(self) -> builtins.str:
             """``CfnWorkGroup.EncryptionConfigurationProperty.EncryptionOption``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-encryptionconfiguration.html#cfn-athena-workgroup-encryptionconfiguration-encryptionoption
             """
             result = self._values.get("encryption_option")
@@ -803,7 +761,6 @@ class CfnWorkGroup(
         def kms_key(self) -> typing.Optional[builtins.str]:
             """``CfnWorkGroup.EncryptionConfigurationProperty.KmsKey``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-encryptionconfiguration.html#cfn-athena-workgroup-encryptionconfiguration-kmskey
             """
             result = self._values.get("kms_key")
@@ -839,7 +796,6 @@ class CfnWorkGroup(
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
             :param output_location: ``CfnWorkGroup.ResultConfigurationProperty.OutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -854,7 +810,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]:
             """``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfiguration.html#cfn-athena-workgroup-resultconfiguration-encryptionconfiguration
             """
             result = self._values.get("encryption_configuration")
@@ -864,7 +819,6 @@ class CfnWorkGroup(
         def output_location(self) -> typing.Optional[builtins.str]:
             """``CfnWorkGroup.ResultConfigurationProperty.OutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfiguration.html#cfn-athena-workgroup-resultconfiguration-outputlocation
             """
             result = self._values.get("output_location")
@@ -906,7 +860,6 @@ class CfnWorkGroup(
             :param remove_encryption_configuration: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveEncryptionConfiguration``.
             :param remove_output_location: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveOutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -925,7 +878,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-encryptionconfiguration
             """
             result = self._values.get("encryption_configuration")
@@ -935,7 +887,6 @@ class CfnWorkGroup(
         def output_location(self) -> typing.Optional[builtins.str]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.OutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-outputlocation
             """
             result = self._values.get("output_location")
@@ -947,7 +898,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveEncryptionConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-removeencryptionconfiguration
             """
             result = self._values.get("remove_encryption_configuration")
@@ -959,7 +909,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.RemoveOutputLocation``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-resultconfigurationupdates.html#cfn-athena-workgroup-resultconfigurationupdates-removeoutputlocation
             """
             result = self._values.get("remove_output_location")
@@ -1004,7 +953,6 @@ class CfnWorkGroup(
             :param requester_pays_enabled: ``CfnWorkGroup.WorkGroupConfigurationProperty.RequesterPaysEnabled``.
             :param result_configuration: ``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -1023,7 +971,6 @@ class CfnWorkGroup(
         def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-bytesscannedcutoffperquery
             """
             result = self._values.get("bytes_scanned_cutoff_per_query")
@@ -1035,7 +982,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.EnforceWorkGroupConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-enforceworkgroupconfiguration
             """
             result = self._values.get("enforce_work_group_configuration")
@@ -1047,7 +993,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.PublishCloudWatchMetricsEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-publishcloudwatchmetricsenabled
             """
             result = self._values.get("publish_cloud_watch_metrics_enabled")
@@ -1059,7 +1004,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.RequesterPaysEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-requesterpaysenabled
             """
             result = self._values.get("requester_pays_enabled")
@@ -1071,7 +1015,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-resultconfiguration
             """
             result = self._values.get("result_configuration")
@@ -1119,7 +1062,6 @@ class CfnWorkGroup(
             :param requester_pays_enabled: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RequesterPaysEnabled``.
             :param result_configuration_updates: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -1140,7 +1082,6 @@ class CfnWorkGroup(
         def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-bytesscannedcutoffperquery
             """
             result = self._values.get("bytes_scanned_cutoff_per_query")
@@ -1152,7 +1093,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EnforceWorkGroupConfiguration``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-enforceworkgroupconfiguration
             """
             result = self._values.get("enforce_work_group_configuration")
@@ -1164,7 +1104,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.PublishCloudWatchMetricsEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-publishcloudwatchmetricsenabled
             """
             result = self._values.get("publish_cloud_watch_metrics_enabled")
@@ -1176,7 +1115,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RemoveBytesScannedCutoffPerQuery``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-removebytesscannedcutoffperquery
             """
             result = self._values.get("remove_bytes_scanned_cutoff_per_query")
@@ -1188,7 +1126,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RequesterPaysEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-requesterpaysenabled
             """
             result = self._values.get("requester_pays_enabled")
@@ -1200,7 +1137,6 @@ class CfnWorkGroup(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationUpdatesProperty"]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-resultconfigurationupdates
             """
             result = self._values.get("result_configuration_updates")
@@ -1240,8 +1176,8 @@ class CfnWorkGroupProps:
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]] = None,
-        work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]] = None,
-        work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]] = None,
+        work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationProperty]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationUpdatesProperty]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::WorkGroup``.
 
@@ -1253,7 +1189,6 @@ class CfnWorkGroupProps:
         :param work_group_configuration: ``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
         :param work_group_configuration_updates: ``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1276,7 +1211,6 @@ class CfnWorkGroupProps:
     def name(self) -> builtins.str:
         """``AWS::Athena::WorkGroup.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-name
         """
         result = self._values.get("name")
@@ -1287,7 +1221,6 @@ class CfnWorkGroupProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-description
         """
         result = self._values.get("description")
@@ -1299,7 +1232,6 @@ class CfnWorkGroupProps:
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::Athena::WorkGroup.RecursiveDeleteOption``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-recursivedeleteoption
         """
         result = self._values.get("recursive_delete_option")
@@ -1309,7 +1241,6 @@ class CfnWorkGroupProps:
     def state(self) -> typing.Optional[builtins.str]:
         """``AWS::Athena::WorkGroup.State``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-state
         """
         result = self._values.get("state")
@@ -1321,7 +1252,6 @@ class CfnWorkGroupProps:
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]]:
         """``AWS::Athena::WorkGroup.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-tags
         """
         result = self._values.get("tags")
@@ -1330,10 +1260,9 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationProperty]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfiguration
         """
         result = self._values.get("work_group_configuration")
@@ -1342,10 +1271,9 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationUpdatesProperty]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-workgroup.html#cfn-athena-workgroup-workgroupconfigurationupdates
         """
         result = self._values.get("work_group_configuration_updates")
